@@ -3,9 +3,9 @@
 
 'use strict';
 
-var device = require('azure-iot-device');
-var Mqtt = require('./dist/mqtt.js').Mqtt;
-var MqttWs = require('./dist/mqtt_ws.js').MqttWs;
+const device = require('azure-iot-device');
+const Mqtt = require('./dist/mqtt.js').Mqtt;
+const MqttWs = require('./dist/mqtt_ws.js').MqttWs;
 
 /**
  * The `azure-iot-device-mqtt` module provides support the MQTT protocol to the device [client]{@link module:azure-iot-device.Client} using secure sockets.
@@ -20,4 +20,4 @@ module.exports = {
   clientFromConnectionString: function (connectionString) {
     return device.Client.fromConnectionString(connectionString, Mqtt);
   }
-};
\ No newline at end of file
+};
